@@ -23,8 +23,11 @@ from qtpy.QtWidgets import QMainWindow, QApplication, QHBoxLayout, QWidget, QMen
 from tsuchinoko.assets import path
 from tsuchinoko.adaptive import Data
 from tsuchinoko.core import CoreState
-from tsuchinoko.core.messages import PauseRequest, StartRequest, GetParametersRequest, SetParameterRequest, PartialDataRequest, FullDataRequest, StopRequest, Message, StateRequest, StateResponse, GetParametersResponse, FullDataResponse, PartialDataResponse, MeasureRequest, \
-    ConnectRequest, ConnectResponse, PushDataRequest, ExceptionResponse, PullGraphsRequest, GraphsResponse
+from tsuchinoko.core.messages import PauseRequest, StartRequest, GetParametersRequest, SetParameterRequest, \
+    PartialDataRequest, FullDataRequest, StopRequest, Message, StateRequest, StateResponse, GetParametersResponse, \
+    FullDataResponse, PartialDataResponse, MeasureRequest, \
+    ConnectRequest, ConnectResponse, PushDataRequest, ExceptionResponse, PullGraphsRequest, GraphsResponse, \
+    ReplayRequest
 from tsuchinoko.graphics_items.clouditem import CloudItem
 from tsuchinoko.graphics_items.indicatoritem import BetterCurveArrow
 from tsuchinoko.graphics_items.mixins import ClickRequester, request_relay, ClickRequesterPlot
@@ -88,6 +91,7 @@ class MainWindow(QMainWindow):
         self.state_manager_widget.sigPause.connect(self.pause)
         self.state_manager_widget.sigStart.connect(self.start)
         self.state_manager_widget.sigStop.connect(self.stop)
+        self.state_manager_widget.sigReplay.connect(self.replay)
         self.configuration_widget.sigPushParameter.connect(self.set_parameter)
         self.configuration_widget.sigRequestParameters.connect(self.request_parameters)
         request_relay.sigRequestMeasure.connect(self.request_measure)
@@ -106,7 +110,7 @@ class MainWindow(QMainWindow):
         self.subscribe(self._data_callback, PartialDataResponse)
         self.subscribe(self.refresh_state, ConnectResponse)
         self.subscribe(self.log_widget.log_exception, ExceptionResponse)
-        self.subscribe(self.graph_manager_widget.set_graphs, GraphsResponse, invoke_as_event=True)
+        self.subscribe(self.set_graphs, GraphsResponse, invoke_as_event=True)
 
     def init_socket(self):
         if self.socket:
@@ -136,6 +140,12 @@ class MainWindow(QMainWindow):
     def stop(self):
         self.message_queue.put(StopRequest())
 
+    def replay(self):
+        message = ReplayRequest(self.data.positions, self.data.measurements)
+        self.message_queue.put(StopRequest())
+        self.message_queue.put(message)
+        self.message_queue.put(StartRequest())
+
     def request_measure(self, pos):
         self.message_queue.put(MeasureRequest(pos))
 
@@ -229,6 +239,9 @@ class MainWindow(QMainWindow):
         # self._update_graph('score', x, y, data.scores)
         # self._update_graph('variance', x, y, data.variances)
 
+    def set_graphs(self, graphs):
+        self.graph_manager_widget.set_graphs(graphs, self.data)
+
     def subscribe(self, callback, response_type: Union[Type[Message], None] = None, invoke_as_event: bool = False):
         self.callbacks[response_type].append((callback, invoke_as_event))
 
@@ -251,8 +264,9 @@ class MainWindow(QMainWindow):
 
         self.data = Data(**load(open(name, 'r'), Loader=Loader))
         self.last_data_size = len(self.data)
-        self.graph_manager_widget.reset()
-        self.update_graphs(self.data, 0)
+        # self.graph_manager_widget.reset()
+        self.message_queue.put(PullGraphsRequest())
+        # self.update_graphs(self.data, 0)
         if self.state_manager_widget.state == CoreState.Connecting:
             logger.warning('Data has been loaded before connecting to an experiment server. Remember to reload data after a connection is established.')
         else:
